@@ -143,8 +143,8 @@ class Cardlist(list):
 
                 # preprocess dates
                 cleaned_dates = {'created_after': created_after,
-                                'created_before': due_before,
-                                     'due_after': created_after,
+                                'created_before': created_before,
+                                     'due_after': due_after,
                                     'due_before': due_before,}
                 # cast dates to myformat: number of days since epoch
                 for key, value in cleaned_dates.items():
