@@ -3,12 +3,11 @@
 import sqlite3 as _sqlite3
 from vinca._cardlist import Cardlist as _Cardlist
 import vinca._config
-from vinca._config import collection_path
+from vinca._config import collection_path, dolt_repo
 from pathlib import Path as _Path
 
 from rich import print as _print
 
-
 collection_path = _Path(collection_path).expanduser()
 _vinca_path = _Path(__file__).parent
 _empty_deck_path = _vinca_path / 'empty_deck.db'
@@ -21,8 +20,13 @@ if not collection_path.exists():
         shutil.copy(_empty_deck_path, collection_path)
         print('empty collection created')
 
-# create default collection
-_cursor = _sqlite3.connect(collection_path).cursor()
+# create collection to db
+_cursor = _sqlite3.connect(collection_path).cursor() if not dolt_repo else dolt_repo.cursor
+# create hooks into dolt functionality
+if dolt_repo:
+        dolt_merge = dolt_repo.ask_and_merge
+        dolt_status = dolt_repo.status
+
 all_cards = _Cardlist(_cursor)
 globals()['-a'] = all_cards
 col = all_cards
